@@ -55,6 +55,15 @@ def backoff_giveup_handler(backoff) -> None:
 class HttpClient:
     """HttpClient class to do http request."""
 
+    def __init__(self) -> None:
+        self.client = httpx.Client()
+
+    def __del__(self) -> None:
+        self.close()
+
+    def close(self) -> None:
+        self.client.close()
+
     def get(self, *args, **kwargs) -> httpx.Response:
         return self.request("GET", *args, **kwargs)
 
@@ -66,10 +75,9 @@ class HttpClient:
         max_time=MAX_BACKOFF_TIME, on_giveup=backoff_giveup_handler
     )
     def request(self, method: str = "GET", *args, **kwargs) -> httpx.Response:
-        with httpx.Client() as client:
-            resp = client.request(method, *args, **kwargs)
-            if resp.status_code >= 500:
-                resp.raise_for_status()
+        resp = self.client.request(method, *args, **kwargs)
+        if resp.status_code >= 500:
+            resp.raise_for_status()
 
         return resp
 
@@ -125,7 +133,8 @@ class DefaultClient:
             at (str): Revoked At
         """
         with self._lock:
-            self._revokedUsers[uid] = parse_nanotimestamp(at)
+            pass
+            # self._revokedUsers[uid] = parse_nanotimestamp(at)
 
     def _get_revoked_user(self, uid: str) -> Any:
         """Get revoked user by ID (thread-safe)
@@ -137,7 +146,8 @@ class DefaultClient:
             Any: Revoked At
         """
         with self._lock:
-            return self._revokedUsers.get(uid)
+            return False
+            # return self._revokedUsers.get(uid)
 
     def _set_revocation_filter(self, filter: BloomFilterJSON) -> None:
         """Set revocation token filter (thread-safe)
@@ -230,7 +240,8 @@ class DefaultClient:
             revocation_list = RevocationList.loads(resp.json())
             self._set_revocation_filter(revocation_list.RevokedTokens)
             for revoked_user in revocation_list.RevokedUsers:
-                self._set_revoked_user(revoked_user.Id, revoked_user.RevokedAt)
+                if revoked_user.Id and revoked_user.RevokedAt:
+                    self._set_revoked_user(revoked_user.Id, revoked_user.RevokedAt)
 
         except (json.JSONDecodeError, ValueError) as e:
             raise GetRevocationListError("unable to unmarshal response body") from e
